==> haskell-insert-ordered-containers-0.2.1.0-33-i686.pkg.tar.xz: usr/share/haskell/register/haskell-insert-ordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: insert-ordered-containers
version: 0.2.1.0
id: insert-ordered-containers-0.2.1.0-1BdmWkPqhCJICooGCFeGDN
key: insert-ordered-containers-0.2.1.0-1BdmWkPqhCJICooGCFeGDN
license: BSD3
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/insert-ordered-containers#readme
synopsis: Associative containers retating insertion order for traversals.
description:
    Associative containers retating insertion order for traversals.
category: Web
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
indefinite: False
exposed-modules:
    Data.HashMap.Strict.InsOrd
abi: 7418c92369a5fc7948360816186d4909
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/insert-ordered-containers-0.2.1.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/insert-ordered-containers-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/insert-ordered-containers-0.2.1.0
hs-libraries: HSinsert-ordered-containers-0.2.1.0-1BdmWkPqhCJICooGCFeGDN
depends:
    base-4.10.0.0 aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y
    base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW
    hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk
    lens-4.15.4-BVNSGosFkEc34U2t4uFumn
    semigroupoids-5.2.1-BrFpsm3Xb4SLTmLSosQvtp
    semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz transformers-0.5.2.0
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=1bd098f0c2fb1217cc4d33a7e7a9941a
             base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW=99c1023c304a14d4b5f863c8a16db1e9
             hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk=c277093fa16e707f51e09b45510f1326
             lens-4.15.4-BVNSGosFkEc34U2t4uFumn=693a07eed940cac4dd3dec3341ea8baa
             semigroupoids-5.2.1-BrFpsm3Xb4SLTmLSosQvtp=bdfa5866cc56e480e7a8a405de65eb0f
             semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP=aad58cc65045b8e62f1806217258d930
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
haddock-interfaces: /usr/share/doc/haskell-insert-ordered-containers/html/insert-ordered-containers.haddock
haddock-html: /usr/share/doc/haskell-insert-ordered-containers/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-insert-ordered-containers-0.2.1.0-34-i686.pkg.tar.xz: usr/share/haskell/register/haskell-insert-ordered-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: insert-ordered-containers
version: 0.2.1.0
id: insert-ordered-containers-0.2.1.0-4A1gjthiIl2FAFgxJTdmVD
key: insert-ordered-containers-0.2.1.0-4A1gjthiIl2FAFgxJTdmVD
license: BSD3
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/insert-ordered-containers#readme
synopsis: Associative containers retating insertion order for traversals.
description:
    Associative containers retating insertion order for traversals.
category: Web
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
indefinite: False
exposed-modules:
    Data.HashMap.Strict.InsOrd
abi: 5c35089951da28703b66ef4d5da7a564
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/insert-ordered-containers-0.2.1.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/insert-ordered-containers-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/insert-ordered-containers-0.2.1.0
hs-libraries: HSinsert-ordered-containers-0.2.1.0-4A1gjthiIl2FAFgxJTdmVD
depends:
    base-4.10.0.0 aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq
    base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW
    hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk
    lens-4.15.4-BVNSGosFkEc34U2t4uFumn
    semigroupoids-5.2.1-BrFpsm3Xb4SLTmLSosQvtp
    semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz transformers-0.5.2.0
    unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             aeson-1.2.3.0-SQQydLO5BXKh1lJDeeNrq=8b90ef7c46d906c8047345fb433e32fe
             base-compat-0.9.3-7gxrulAnYCf9OVK5Ok3lMW=99c1023c304a14d4b5f863c8a16db1e9
             hashable-1.2.6.1-5D85BzUWIsjDNuFvtLMWyk=c277093fa16e707f51e09b45510f1326
             lens-4.15.4-BVNSGosFkEc34U2t4uFumn=693a07eed940cac4dd3dec3341ea8baa
             semigroupoids-5.2.1-BrFpsm3Xb4SLTmLSosQvtp=bdfa5866cc56e480e7a8a405de65eb0f
             semigroups-0.18.3-6KPIVJcHqOOBHjBl8WA5LP=aad58cc65045b8e62f1806217258d930
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             unordered-containers-0.2.8.0-KL4HUdwCmhYBQDTvY5v0GN=7d7e1f3460b904c0be93ffa55855f4d0
haddock-interfaces: /usr/share/doc/haskell-insert-ordered-containers/html/insert-ordered-containers.haddock
haddock-html: /usr/share/doc/haskell-insert-ordered-containers/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
